@@ -8,10 +8,10 @@ import json
 import logging
 import os
 from pathlib import Path
-from PIL import Image
 import re
 import sys
 from threading import Thread
+import warnings
 import yaml
 import _thread
 
@@ -279,7 +279,7 @@ def load_huggingface_api_key():
     return load_api_key('huggingface')
 
 
-def load_api_key(name):
+def load_api_key(name, raise_error=True):
     """Generic api key loader. Assumes you store the key as a text file
     containing only one key in a file called ~/.{name}.
 
@@ -287,13 +287,39 @@ def load_api_key(name):
     ----------
     name: str
         Examples: 'booste', 'huggingface', 'gooseai'.
+    raise_error: bool
+        If True, a missing file will raise an error. If False, a missing file
+        will only cause a warning and will return an empty string.
 
     Returns
     -------
     str
     """
-    with open(Path(f'~/.{name}').expanduser(), 'r') as f:
-        return f.read().strip()
+    def _load_key(name):
+        """Load api key or raise FileNotFoundError. We also check for
+        an environment variable like OPENAI_API_KEY.
+        """
+        try:
+            with open(Path(f'~/.{name}').expanduser(), 'r') as f:
+                return f.read().strip()
+        except FileNotFoundError as e:
+            key = os.getenv(f'{name.upper()}_API_KEY')
+            if key: return key
+            raise e
+
+    if raise_error:
+        return _load_key(name)
+    try:
+        return _load_key(name)
+    except FileNotFoundError:
+        warnings.warn(
+            f'Jabberwocky expected to find an api key for backend '
+            f'{name} but couldn\'t. Using {name} backend will throw '
+            f'auth errors. Add your api key to "~/.{name} (if you are using a '
+            f'GPTBackend object, you will then need to use its '
+            f'refresh_api_keys method to enable the backend.'
+        )
+        return ''
 
 
 load_goose_api_key = partial(load_api_key, name='gooseai')
@@ -435,7 +461,6 @@ def most_recent_filepath(dir_, mode='m'):
     return max(paths, key=lambda x: getattr(x.stat(), f'st_{mode}time'))
 
 
-
 def set_module_global(module, key, value):
     """Create global variable in an imported module. This is a slightly hacky
     workaround that solves some types of circular imports.
